/**
 * ### Менеджер моделей.
 *
 * Представляет собой интерфейс для доступа ко всем моделям
 *
 * Позволяет по адресу модели, получить на нее ссылку.
 *
 * ```bash
 * // доступ
 * ps.pl.mm
 * ```
 *
 *
 * <br>
 * Связанные объекты:
 *
 * - {@link Models.Model Model} - Модель (устройство, девайс). Доступ к данным модели
 * - {@link Models.AlarmType AlarmType} - Тип аварии(аларма). Предоставляет доступ к данным типа аварии.
 *
 * @group manager
 * @namespace Models
 * @extends manager
 */
function Models() {
    /**
     *  Вернет ссылку на модель.
     *
     *  В качестве идентификатора следует указать адрес дерева.
     *
     * Пример
     * ```
     * ps.pl.mm.get(new v2.address(["system_address", "some", "model", "address"])).then(function(_ref){
     *     var model = _ref.value();
     *     // теперь можно работать с провайдером модели
     * }, function(_err){
     *     console.log("произошла ошибка")
     * });
     * ```
     * @public
     * @function get
     * @param {v2.address} address Адрес модели
     * @returns {tools.promise(Models.Model)}
     * @memberof Models
     */
    this.get = function (address) {

    };

    /**
     *  #### Загрузит все объекты, которые попадают в указанную область.
     *
     * @public
     * @function gis_bound
     * @param {v2.float} _sw_lat широта:  нижний левый угол
     * @param {v2.float} _sw_lon долгота: нижний левый угол
     * @param {v2.float} _ne_lat широта:  верхний правый угол
     * @param {v2.float} _ne_lon долгота: верхний правый угол
     * @returns {tools.promise(v2.list(v2.vc))}
     * @memberof Models
     */
    this.gis_bound = function (_sw_lat, _sw_lon, _ne_lat, _ne_lon) {

    };


    /**
     *  #### Загрузит все объекты, которые попадают в указанную область.
     *
     * @public
     * @function get_alarm_type
     * @returns {tools.promise(Models.AlarmType)}
     * @memberof Models
     */
    this.get_alarm_type = function () {

    };


}